@@ -126,7 +126,7 @@ class SortableAdminMixin(SortableAdminBase):
         setattr(func, 'allow_tags', True)
         setattr(func, 'short_description', _('Sort'))
         setattr(func, 'admin_order_field', self.default_order_field)
-        setattr(self, '_reorder', MethodType(func, self, type(self)))
+        setattr(self, '_reorder', MethodType(func, self))
 
     @csrf_exempt
     def update(self, request):
@@ -270,7 +270,7 @@ class CustomInlineFormSet(BaseInlineFormSet):
 
 class SortableInlineAdminMixin(SortableAdminBase):
     formset = CustomInlineFormSet
-    
+
     def __init__(self, parent_model, admin_site):
         version = (VERSION[0] == 1 and VERSION[1] <= 5) and '1.5' or '1.6'
         if isinstance(self, admin.StackedInline):
